@@ -3,7 +3,7 @@ import os
 import subprocess
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Generator, Union
+from typing import Any, Generator, Union
 
 __version__ = importlib.metadata.version("pysh")
 
@@ -23,7 +23,9 @@ class CompletedProcessWrapper:
         return self.returncode == 0  # type: ignore
 
 
-def sh(*argv, capture: Union[bool, None] = None, cwd: Union[str, Path] = ".", **kwargs) -> subprocess.CompletedProcess:
+def sh(
+    *argv: str, capture: Union[bool, None] = None, cwd: Union[str, Path] = ".", **kwargs: Any
+) -> "subprocess.CompletedProcess[str]":
     kwargs["stdin"] = subprocess.PIPE
     kwargs["shell"] = True
     kwargs["text"] = True
@@ -50,13 +52,14 @@ def cd(path: Union[str, Path]) -> Generator[Path, None, None]:
 
 
 @contextmanager
-def env(key: str, value: str) -> Generator[str, None, None]:
-    old_value = os.environ.get(key)
-    os.environ[key] = value
+def env(**kwargs: str) -> Generator[None, None, None]:
+    old_values = {key: os.environ.get(key) for key in kwargs}
+    os.environ.update(kwargs)
 
-    yield value
+    yield
 
-    if old_value is not None:
-        os.environ[key] = old_value
-    else:
-        del os.environ[key]
+    for key, value in old_values.items():
+        if value is not None:
+            os.environ[key] = value
+        else:
+            del os.environ[key]
